@@ -1,26 +1,10 @@
-/****************************************************************************
-**
-** Copyright (C) 2002-2003 Tim Jansen <tim@tjansen.de>
-** Copyright (C) 2007-2008 Urs Wolfer <uwolfer @ kde.org>
-**
-** This file is part of KDE.
-**
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
-**
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with this program; see the file COPYING. If not, write to
-** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-** Boston, MA 02110-1301, USA.
-**
-****************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2002-2003 Tim Jansen <tim@tjansen.de>
+    SPDX-FileCopyrightText: 2007-2008 Urs Wolfer <uwolfer@kde.org>
+    SPDX-FileCopyrightText: 2021 Rafał Lalik <rafallalik@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "remoteview.h"
 #include "krdc_debug.h"
@@ -38,6 +22,7 @@ RemoteView::RemoteView(QWidget *parent)
         m_grabAllKeys(false),
         m_scale(false),
         m_keyboardIsGrabbed(false),
+        m_factor(0.),
 #ifndef QTONLY
         m_wallet(nullptr),
 #endif
@@ -73,18 +58,18 @@ void RemoteView::setStatus(RemoteView::RemoteStatus s)
             Q_ASSERT(((int) s) >= 0);
             if (m_status > s) {
                 m_status = Disconnected;
-                emit statusChanged(Disconnected);
+                Q_EMIT statusChanged(Disconnected);
             }
             // smooth state transition
             RemoteStatus origState = m_status;
             for (int i = origState; i < s; ++i) {
                 m_status = (RemoteStatus) i;
-                emit statusChanged((RemoteStatus) i);
+                Q_EMIT statusChanged((RemoteStatus) i);
             }
         }
     }
     m_status = s;
-    emit statusChanged(m_status);
+    Q_EMIT statusChanged(m_status);
 }
 
 bool RemoteView::supportsScaling() const
@@ -186,6 +171,11 @@ void RemoteView::enableScaling(bool scale)
     m_scale = scale;
 }
 
+void RemoteView::setScaleFactor(float factor)
+{
+    m_factor = factor;
+}
+
 void RemoteView::switchFullscreen(bool)
 {
 }
