@@ -1,27 +1,10 @@
-/****************************************************************************
-**
-** Copyright (C) 2007-2008 Urs Wolfer <uwolfer @ kde.org>
-** Parts of this file have been take from okular:
-** Copyright (C) 2004-2005 Enrico Ros <eros.kde@email.it>
-**
-** This file is part of KDE.
-**
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
-**
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with this program; see the file COPYING. If not, write to
-** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-** Boston, MA 02110-1301, USA.
-**
-****************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007-2008 Urs Wolfer <uwolfer@kde.org>
+    Parts of this file have been take from okular:
+    SPDX-FileCopyrightText: 2004-2005 Enrico Ros <eros.kde@email.it>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "floatingtoolbar.h"
 #include "krdc_debug.h"
@@ -271,7 +254,7 @@ void FloatingToolBar::mouseMoveEvent(QMouseEvent *e)
 
     d->anchorSide = side;
     d->reposition();
-    emit orientationChanged((int)side);
+    Q_EMIT orientationChanged((int)side);
 
     QToolBar::mouseMoveEvent(e);
 }
@@ -348,9 +331,9 @@ void FloatingToolBarPrivate::buildToolBar()
     mask.fill(Qt::white);
     maskPainter.setBrush(Qt::black);
     if (vertical)
-        maskPainter.drawRoundRect(topLeft ? -10 : 0, 0, myWidth + 10, myHeight, 2000 / (myWidth + 10), 2000 / myHeight);
+        maskPainter.drawRoundedRect(topLeft ? -10 : 0, 0, myWidth + 10, myHeight, 2000 / (myWidth + 10), 2000 / myHeight, Qt::RelativeSize);
     else
-        maskPainter.drawRoundRect(0, topLeft ? -10 : 0, myWidth, myHeight + 10, 2000 / myWidth, 2000 / (myHeight + 10));
+        maskPainter.drawRoundedRect(0, topLeft ? -10 : 0, myWidth, myHeight + 10, 2000 / myWidth, 2000 / (myHeight + 10), Qt::RelativeSize);
     maskPainter.end();
     q->setMask(mask);
 
@@ -381,9 +364,9 @@ void FloatingToolBarPrivate::buildToolBar()
     bufferPainter.setPen( pal.color(QPalette::Active, QPalette::Dark).lighter(40));
     bufferPainter.setRenderHints(QPainter::Antialiasing);
     if (vertical)
-        bufferPainter.drawRoundRect(topLeft ? -10 : 0, 0, myWidth + 10, myHeight, 2000 / (myWidth + 10), 2000 / myHeight);
+        bufferPainter.drawRoundedRect(topLeft ? -10 : 0, 0, myWidth + 10, myHeight, 2000 / (myWidth + 10), 2000 / myHeight, Qt::RelativeSize);
     else
-        bufferPainter.drawRoundRect(0, topLeft ? -10 : 0, myWidth, myHeight + 10, 2000 / myWidth, 2000 / (myHeight + 10));
+        bufferPainter.drawRoundedRect(0, topLeft ? -10 : 0, myWidth, myHeight + 10, 2000 / myWidth, 2000 / (myHeight + 10), Qt::RelativeSize);
     // 5.3. draw handle
     bufferPainter.translate(-0.5, -0.5);
     bufferPainter.setPen(pal.color(QPalette::Active, QPalette::Mid));
