@@ -1,25 +1,8 @@
-/****************************************************************************
-**
-** Copyright (C) 2009 Urs Wolfer <uwolfer @ kde.org>
-**
-** This file is part of KDE.
-**
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
-**
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with this program; see the file COPYING. If not, write to
-** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-** Boston, MA 02110-1301, USA.
-**
-****************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009 Urs Wolfer <uwolfer@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "konsoleview.h"
 
@@ -49,7 +32,7 @@ KonsoleView::KonsoleView(QWidget *parent, const QUrl &url, KConfigGroup configGr
     setStatus(Connected);
     setFixedSize(size);
     setFixedSize(size);
-    emit framebufferSizeChanged(size.width(), size.height());
+    Q_EMIT framebufferSizeChanged(size.width(), size.height());
 
     KPluginFactory* factory = 0;
     KService::Ptr service = KService::serviceByDesktopName("konsolepart");
@@ -74,7 +57,7 @@ KonsoleView::KonsoleView(QWidget *parent, const QUrl &url, KConfigGroup configGr
 
 KonsoleView::~KonsoleView()
 {
-    emit disconnected();
+    Q_EMIT disconnected();
     setStatus(Disconnected);
 }
 
@@ -111,7 +94,7 @@ bool KonsoleView::isQuitting()
 bool KonsoleView::start()
 {
     setStatus(Connected);
-    emit connected();
+    Q_EMIT connected();
     m_terminalWidget->setFocus();
     return true;
 }
