@@ -1,33 +1,16 @@
-/****************************************************************************
-**
-** Copyright (C) 2001-2003 Tim Jansen <tim@tjansen.de>
-** Copyright (C) 2007 - 2012 Urs Wolfer <uwolfer @ kde.org>
-**
-** This file is part of KDE.
-**
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
-**
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with this program; see the file COPYING. If not, write to
-** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-** Boston, MA 02110-1301, USA.
-**
-****************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2001-2003 Tim Jansen <tim@tjansen.de>
+    SPDX-FileCopyrightText: 2007-2012 Urs Wolfer <uwolfer@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "mainwindow.h"
 #include "krdc_debug.h"
 #include "krdc_version.h"
 #include "settings.h"
 
-#include <KCoreAddons/KAboutData>
+#include <KAboutData>
 #include <Kdelibs4ConfigMigrator>
 #include <Kdelibs4Migration>
 #include <KLocalizedString>
@@ -62,9 +45,9 @@ int main(int argc, char **argv)
             if (!targetDir.exists()) {
                 QDir().mkpath(targetBasePath);
             }
-            QStringList fileNames = sourceDir.entryList(QDir::Files |
+            const QStringList fileNames = sourceDir.entryList(QDir::Files |
                                     QDir::NoDotAndDotDot | QDir::NoSymLinks);
-            foreach (const QString &fileName, fileNames) {
+            for (const QString &fileName : fileNames) {
                 targetFilePath = targetBasePath + fileName;
                 if (!QFile::exists(targetFilePath)) {
                     QFile::copy(sourceBasePath + fileName, targetFilePath);
