@@ -1,26 +1,10 @@
-/****************************************************************************
-**
-** Copyright (C) 2007 - 2013 Urs Wolfer <uwolfer @ kde.org>
-** Copyright (C) 2009 - 2010 Tony Murray <murraytony @ gmail.com>
-**
-** This file is part of KDE.
-**
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
-**
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with this program; see the file COPYING. If not, write to
-** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-** Boston, MA 02110-1301, USA.
-**
-****************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007-2013 Urs Wolfer <uwolfer@kde.org>
+    SPDX-FileCopyrightText: 2009-2010 Tony Murray <murraytony@gmail.com>
+    SPDX-FileCopyrightText: 2021 Rafał Lalik <rafallalik@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
@@ -28,8 +12,8 @@
 #include "remoteview.h"
 #include "remoteviewfactory.h"
 
-#include <KXmlGui/KXmlGuiWindow>
-#include <KService/KPluginInfo>
+#include <KXmlGuiWindow>
+#include <KPluginInfo>
 
 class KComboBox;
 class KLineEdit;
@@ -65,6 +49,7 @@ public:
 
 public Q_SLOTS:
     void newConnection(const QUrl &newUrl = QUrl(), bool switchFullscreenWhenConnected = false, const QString &tabName = QString());
+    void setFactor(int scale);
 
 protected:
     void closeEvent(QCloseEvent *event) override;
@@ -133,6 +118,10 @@ private:
     QTableView *m_newConnectionTableView;
     RemoteDesktopsModel *m_remoteDesktopsModel;
     QWidget *m_newConnectionWidget;
+
+Q_SIGNALS:
+    void scaleUpdated(bool scale);  // scale state has changed
+    void factorUpdated(int factor); // factor havlue has changed
 };
 
 #include <QApplication>
@@ -155,7 +144,7 @@ Q_SIGNALS:
 protected:
     void mousePressEvent(QMouseEvent *event) override {
         if (event->button() == Qt::RightButton)
-            emit rightClicked();
+            Q_EMIT rightClicked();
     }
 };
 
@@ -175,7 +164,7 @@ Q_SIGNALS:
 protected:
     void resizeEvent(QResizeEvent *event) override {
         QScrollArea::resizeEvent(event);
-        emit resized(width() - 2*frameWidth(), height() - 2*frameWidth());
+        Q_EMIT resized(width() - 2*frameWidth(), height() - 2*frameWidth());
     }
 };
 
