@@ -1,25 +1,8 @@
-/****************************************************************************
-**
-** Copyright (C) 2007 - 2013 Urs Wolfer <uwolfer @ kde.org>
-**
-** This file is part of KDE.
-**
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
-**
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with this program; see the file COPYING. If not, write to
-** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-** Boston, MA 02110-1301, USA.
-**
-****************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007-2013 Urs Wolfer <uwolfer@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "vncclientthread.h"
 #include "krdc_debug.h"
@@ -135,7 +118,7 @@ void VncClientThread::cursorShapeHandlerStatic(rfbClient *cl, int xhot, int yhot
     QPixmap cursorPixmap(QPixmap::fromImage(cursorImg));
     cursorPixmap.setMask(QBitmap::fromImage(alpha));
 
-    emit t->gotCursor({cursorPixmap, xhot, yhot});
+    Q_EMIT t->gotCursor({cursorPixmap, xhot, yhot});
 }
 
 void VncClientThread::setClientColorDepth(rfbClient* cl, VncClientThread::ColorDepth cd)
@@ -197,6 +180,9 @@ rfbBool VncClientThread::newclient()
 
     const int width = cl->width, height = cl->height, depth = cl->format.bitsPerPixel;
     const int size = width * height * (depth / 8);
+    if (size <= 0) {
+        return false;
+    }
     if (frameBuffer)
         delete [] frameBuffer; // do not leak if we get a new framebuffer size
     frameBuffer = new uint8_t[size];
@@ -510,12 +496,12 @@ const QImage VncClientThread::image(int x, int y, int w, int h)
 
 void VncClientThread::emitUpdated(int x, int y, int w, int h)
 {
-    emit imageUpdated(x, y, w, h);
+    Q_EMIT imageUpdated(x, y, w, h);
 }
 
 void VncClientThread::emitGotCut(const QString &text)
 {
-    emit gotCut(text);
+    Q_EMIT gotCut(text);
 }
 
 void VncClientThread::stop()
@@ -705,7 +691,7 @@ void VncClientThread::clientSetKeepalive()
 void VncClientThread::clientStateChange(RemoteView::RemoteStatus status, const QString &details)
 {
     qCDebug(KRDC) << status << details << m_host << ":" << m_port;
-    emit clientStateChanged(status, details);
+    Q_EMIT clientStateChanged(status, details);
 }
 
 ClientEvent::~ClientEvent()
