@@ -212,16 +212,13 @@ bool VncView::start()
     m_quitFlag = false;
 
     QString vncHost = m_host;
-    int vncPort = m_port;
 #ifdef LIBSSH_FOUND
     if (m_hostPreferences->useSshTunnel()) {
         Q_ASSERT(!m_sshTunnelThread);
 
-        const int tunnelPort = 58219; // Just a random port
-
         m_sshTunnelThread = new VncSshTunnelThread(m_host.toUtf8(),
                                                    m_port,
-                                                   tunnelPort,
+                                                   /* tunnelPort */ 0,
                                                    m_hostPreferences->sshTunnelPort(),
                                                    m_hostPreferences->sshTunnelUserName().toUtf8(),
                                                    m_hostPreferences->useSshTunnelLoopback());
@@ -232,12 +229,10 @@ bool VncView::start()
         if (m_hostPreferences->useSshTunnelLoopback()) {
             vncHost = QStringLiteral("127.0.0.1");
         }
-        vncPort = tunnelPort;
     }
 #endif
 
     vncThread.setHost(vncHost);
-    vncThread.setPort(vncPort);
     RemoteView::Quality quality;
 #ifdef QTONLY
     quality = (RemoteView::Quality)((QCoreApplication::arguments().count() > 2) ?
@@ -264,11 +259,15 @@ bool VncView::start()
 
 #ifdef LIBSSH_FOUND
     if (m_hostPreferences->useSshTunnel()) {
-        connect(m_sshTunnelThread, &VncSshTunnelThread::listenReady, this, [this] { vncThread.start(); });
+        connect(m_sshTunnelThread, &VncSshTunnelThread::listenReady, this, [this] {
+            vncThread.setPort(m_sshTunnelThread->tunnelPort());
+            vncThread.start();
+        });
     }
     else
 #endif
     {
+        vncThread.setPort(m_port);
         vncThread.start();
     }
     return true;
@@ -535,9 +534,10 @@ void VncView::enableScaling(bool scale)
 
 void VncView::setCut(const QString &text)
 {
+    const bool saved_dontSendClipboard = m_dontSendClipboard;
     m_dontSendClipboard = true;
     m_clipboard->setText(text, QClipboard::Clipboard);
-    m_dontSendClipboard = false;
+    m_dontSendClipboard = saved_dontSendClipboard;
 }
 
 void VncView::paintEvent(QPaintEvent *event)
@@ -603,14 +603,14 @@ void VncView::mouseEventHandler(QMouseEvent *e)
                 (e->type() == QEvent::MouseButtonDblClick)) {
             if (e->button() & Qt::LeftButton)
                 m_buttonMask |= 0x01;
-            if (e->button() & Qt::MidButton)
+            if (e->button() & Qt::MiddleButton)
                 m_buttonMask |= 0x02;
             if (e->button() & Qt::RightButton)
                 m_buttonMask |= 0x04;
         } else if (e->type() == QEvent::MouseButtonRelease) {
             if (e->button() & Qt::LeftButton)
                 m_buttonMask &= 0xfe;
-            if (e->button() & Qt::MidButton)
+            if (e->button() & Qt::MiddleButton)
                 m_buttonMask &= 0xfd;
             if (e->button() & Qt::RightButton)
                 m_buttonMask &= 0xfb;
